@@ -297,6 +297,11 @@ class LackeyStorage:
                         task = self._markdown_to_task(content)
 
                         # Search in various fields
+                        # Get notes content for search
+                        notes_content = []
+                        for note in task.note_manager.get_notes():
+                            notes_content.append(note.content)
+
                         searchable_text = " ".join(
                             [
                                 task.title,
@@ -304,7 +309,7 @@ class LackeyStorage:
                                 task.context or "",
                                 " ".join(task.steps),
                                 " ".join(task.success_criteria),
-                                " ".join(task.notes),
+                                " ".join(notes_content),
                                 task.results or "",
                             ]
                         ).lower()
@@ -474,6 +479,9 @@ class LackeyStorage:
         if task.blocks:
             frontmatter["blocks"] = list(task.blocks)
 
+        if task.status_history:
+            frontmatter["status_history"] = task.status_history
+
         # Build markdown content
         lines = ["---"]
 
@@ -516,11 +524,30 @@ class LackeyStorage:
         lines.append("")
 
         # Add notes if present
-        if task.notes:
+        if len(task.note_manager) > 0:
             lines.append("## Notes")
-            for note in task.notes:
-                lines.append(note)
             lines.append("")
+            for note in task.note_manager:
+                # Format: ### Note {id} ({type}) - {timestamp} by {author}
+                timestamp = note.created.strftime("%Y-%m-%d %H:%M:%S.%f")
+                author_part = f" by {note.author}" if note.author else ""
+                tags_part = f" #{' #'.join(note.tags)}" if note.tags else ""
+
+                note_header = (
+                    f"### Note {note.id} ({note.note_type.value}) - "
+                    f"{timestamp}{author_part}{tags_part}"
+                )
+                lines.append(note_header)
+                lines.append(note.content)
+
+                # Add metadata if present
+                if note.metadata:
+                    lines.append("")
+                    lines.append("**Metadata:**")
+                    for key, value in note.metadata.items():
+                        lines.append(f"- {key}: {value}")
+
+                lines.append("")
 
         # Add results if present
         if task.results:
@@ -563,6 +590,7 @@ class LackeyStorage:
             "tags": frontmatter.get("tags", []),
             "dependencies": set(frontmatter.get("dependencies", [])),
             "blocks": set(frontmatter.get("blocks", [])),
+            "status_history": frontmatter.get("status_history", []),
             "objective": sections.get("Objective", ""),
             "context": sections.get("Context"),
             "steps": self._parse_steps(sections.get("Steps", "")),
@@ -628,11 +656,100 @@ class LackeyStorage:
                 items.append(line[2:])
         return items
 
-    def _parse_notes(self, notes_content: str) -> List[str]:
-        """Parse notes from markdown content."""
+    def _parse_notes(self, notes_content: str) -> List[Dict[str, Any]]:
+        """Parse notes from structured markdown content."""
         if not notes_content.strip():
             return []
 
-        # Split by lines and filter out empty lines
-        notes = [line.strip() for line in notes_content.split("\n") if line.strip()]
-        return notes
+        notes_data = []
+        lines = notes_content.strip().split("\n")
+        i = 0
+
+        while i < len(lines):
+            line = lines[i].strip()
+
+            # Look for note headers: ### Note {id} ({type}) - {timestamp} by {author}
+            if line.startswith("### Note "):
+                # Parse the header
+                import re
+                from datetime import datetime
+
+                # Pattern: ### Note {id} ({type}) - {timestamp}[ by {author}][ #{tags}]
+                pattern = (
+                    r"### Note ([^\s]+) \(([^)]+)\) - ([^#]+?)"
+                    r"(?:\s+by\s+([^#]+?))?(?:\s+(#.+))?$"
+                )
+                match = re.match(pattern, line)
+
+                if match:
+                    note_id, note_type, timestamp_str, author, tags_str = match.groups()
+
+                    # Parse timestamp
+                    try:
+                        created = datetime.strptime(
+                            timestamp_str.strip(), "%Y-%m-%d %H:%M:%S.%f"
+                        )
+                    except ValueError:
+                        created = datetime.utcnow()
+
+                    # Parse tags
+                    tags = []
+                    if tags_str:
+                        tags = [
+                            tag.strip("#") for tag in tags_str.split("#") if tag.strip()
+                        ]
+
+                    # Get content (next non-empty line)
+                    i += 1
+                    content_lines = []
+                    metadata = {}
+
+                    # Read content and metadata
+                    while i < len(lines):
+                        current_line = lines[i].strip()
+
+                        # Stop if we hit another note header or end
+                        if current_line.startswith(
+                            "### Note "
+                        ) or current_line.startswith("## "):
+                            break
+
+                        # Check for metadata section
+                        if current_line == "**Metadata:**":
+                            i += 1
+                            # Parse metadata items
+                            while i < len(lines):
+                                meta_line = lines[i].strip()
+                                if meta_line.startswith("- ") and ":" in meta_line:
+                                    key, value = meta_line[2:].split(":", 1)
+                                    metadata[key.strip()] = value.strip()
+                                    i += 1
+                                else:
+                                    break
+                            continue
+
+                        # Regular content line
+                        if current_line:
+                            content_lines.append(current_line)
+
+                        i += 1
+
+                    # Create note data
+                    notes_data.append(
+                        {
+                            "id": note_id,
+                            "content": "\n".join(content_lines),
+                            "note_type": note_type,
+                            "created": created.isoformat(),
+                            "author": author.strip() if author else None,
+                            "metadata": metadata,
+                            "tags": tags,
+                        }
+                    )
+
+                    # Don't increment i here since the while loop already did
+                    continue
+
+            i += 1
+
+        return notes_data
